@@ -11,7 +11,7 @@
 # * name comes from http://www.thefreedictionary.com/cleave      #
 ##################################################################
 
-Version = '1.7'
+Version = '1.8'
 Build = '1'
 
 import sys
@@ -93,17 +93,15 @@ class clevenMainWindow(QtGui.QMainWindow): # need fixes
        QtCore.QObject.connect(self.ui.authenticateButton, QtCore.SIGNAL('clicked()'), self.executeAuthenticate)
        QtCore.QObject.connect(self.ui.deauthenticateButton, QtCore.SIGNAL('clicked()'), self.executeDeauthenticate)
        QtCore.QObject.connect(self.ui.injectionButton, QtCore.SIGNAL('clicked()'), self.executeInjection)
-       
-       self.showStartupDialog()
-       self.showConfigureDriversDialog() ## Uncomment for pop-up of the configuration dialog at start-up  
+
+       self.showStartupDialog()          ## (Un)comment for pop-up of the start-up dialog at start-up
+       self.showConfigureDriversDialog() ## (Un)comment for pop-up of the configuration dialog at start-up  
+
        self.ui.captureButton.setEnabled(False)
        self.ui.injectionButton.setHidden(True)
        self.ui.authenticateButton.setHidden(True)
        self.ui.deauthenticateButton.setHidden(True)
-
-       self.timer = QtCore.QBasicTimer()
-       self.step = 0
-       
+      
        ##Show some info in the UI
        self.ui.textBrowser.clear()
        self.ui.textBrowser.append('Scan first for available networks')
@@ -281,6 +279,7 @@ class clevenConfigureDrivers(QtGui.QDialog): # Complete
        QtCore.QObject.connect(self.ui.ASK, QtCore.SIGNAL('clicked()'), self.setConnectionBehaviour)
        
        ##Get and populate the UI with the curent info 
+       self.getKernelVersion()
        self.getDriversState()
        self.getInterfaceState()
        self.getConnectionBehaviour()
@@ -288,6 +287,23 @@ class clevenConfigureDrivers(QtGui.QDialog): # Complete
        global myMAC
        myMAC = self.getMAC()
 
+    def getKernelVersion(self):
+
+       global kernelVersion
+       kernelVersion = os.popen('uname -r').read()
+       print kernelVersion
+       
+       if kernelVersion == '2.6.28.10power46-wl1\n':
+          pass
+       elif kernelVersion == '2.6.28.10power47\n':
+          pass
+       elif kernelVersion == '2.6.28.10power48\n':
+          pass
+       else: 
+          message = 'WARNING: The system did not find a compatible kernel version for the injection drivers.\n\nThe application might not work properly..'
+          showMessage(message)
+
+    
     def getDriversState(self):
        '''Check the state of the Drivers (Stock/Bleeding)'''
        
@@ -722,12 +738,12 @@ class clevenStartup(QtGui.QDialog): # Complete
 
     def timerEvent(self, event):
 
-       if self.step >= 100:
+       if self.step >= 100 or self.ui.skipIntroRadioButton.isChecked():
           self.timer.stop()
           self.close()
        self.step = self.step + 1
        self.ui.progressBarStart.setValue(self.step)
-
+    
 class clevenMain(): # Complete
 
     ##Check with what priviledges the GUI has been executed.
